@@ -413,8 +413,8 @@ class ISchedulerLocker(Interface):
     def getJobsStore(self, scheduler):
         """Return APScheduler jobs store"""
 
-    def getLock(self, scheduler, task):
-        """Try to get lock for given task"""
+    def getLock(self, scheduler, task=None):
+        """Try to get lock for given task or for the whole scheduler"""
 
     def releaseLock(self, lock):
         """Release given lock
