@@ -200,7 +200,7 @@ class Scheduler(Folder, SiteManagerContainer):
             return None
         return queryUtility(ISchedulerLocker, self.locker_name)
 
-    def getLock(self, task):
+    def getLock(self, task=None):
         if not self.locker_name:
             return True
         locker = self.getLocker()
